/**
 * gallery.js
 *
 * Applies a unique treatment to the WooCommerce product gallery.
 * * Adds the featured image to the gallery thumbnails as WooCommerce core doesn't do this by defaults
 * * Removes the href attribute from thumbnail links - seeing as we're replacing the main image we don't need to open a lightbox
 * * Switches the main product image with the one clicked in the available thumbnails.
 */
( function( $ ) {
	$( '.thumbnails a' ).removeAttr( 'data-rel' );
	$( '.images img' ).removeAttr( 'srcset' );
	$( '.thumbnails a' ).removeClass( 'zoom' );

	$( document ).ready( function() {
		/**
		 * Add the featured image to the thumbnails
		 */
		var mainImgSrc   = $( '.woocommerce-main-image img' ).attr( 'src' ),
			mainImgAlt   = $( '.woocommerce-main-image img' ).attr( 'alt' ),
			mainImgTitle = $( '.woocommerce-main-image img' ).attr( 'title' );

		$( '.thumbnails' ).prepend( '<a class="active"><img title="' + mainImgTitle + '" alt="' + mainImgAlt + '" src="' + mainImgSrc + '" /></a>' );

		/**
		 * Remove the href on thumbnail links - we don't want to open a lightbox
		 */
		$( '.thumbnails a' ).removeAttr( 'href' );

		/**
		 * Switch the src/alt/title attribute of the featured image with the one clicked in the thumbnails.
		 */
		$( '.thumbnails a' ).each( function() {
			$( this ).click( function() {
				var aimg = $( this ).find( 'img' );

				$( '.thumbnails a' ).removeClass( 'active' );
				$( this ).addClass( 'active' );
				$( '.woocommerce-main-image img' ).fadeOut( 'fast', function() {
					$( this ).attr( 'src', $( aimg ).attr( 'src' ) ).attr( 'alt', $( aimg ).attr( 'alt' ) ).attr( 'title', $( aimg ).attr( 'title' ) ).fadeIn( 'fast' );
				});
				$( '.woocommerce-main-image' ).attr( 'href', $( aimg ).attr( 'src' ) ).attr( 'title', $( aimg ).attr( 'title' ) );
			});
		});
	});
} )( jQuery );