<?php
/**
 * Hotel_Template Class
 *
 * @author   WooThemes
 * @package  Hotel
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Hotel_Template' ) ) {
	/**
	 * The Hotel Template Class
	 */
	class Hotel_Template {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			// We need to use some Conditional Tags, we have to load a few things through the "wp" hook instead.
			add_action( 'wp', array( $this, 'custom_markup_load' ) );
		}

		/**
		 * Custom markup
		 *
		 * @return void
		 */
		public function custom_markup_load() {
			global $post, $storefront_version;


			// Remove header search.
			remove_action( 'storefront_header', 'storefront_product_search',  40 );
			remove_action( 'storefront_header', 'storefront_header_cart', 60 );

			// Move Breadcrumb & Shop messages.
			if ( version_compare( $storefront_version, '2.3.0', '<' ) ) {
				remove_action( 'storefront_content_top', 'woocommerce_breadcrumb', 10 );
			} else {
				remove_action( 'storefront_before_content', 'woocommerce_breadcrumb', 10 );
			}

			// Remove add to cart button from product loops.
			$add_to_cart_visible = get_theme_mod( 'swc_product_archive_add_to_cart' );
			if ( ! $add_to_cart_visible ) {
				remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
			}

			/* Remove thumbnail from default location */
			remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );

			/* Loop Product Thumbnail */
			add_action( 'woocommerce_before_shop_loop_item', array( $this, 'hotel_loop_thumbnail_wrapper_before' ), 1 );
			add_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_thumbnail', 2 );
			add_action( 'woocommerce_before_shop_loop_item', array( $this, 'hotel_loop_thumbnail_wrapper_after' ), 3 );

			/* Loop Product Content */
			add_action( 'woocommerce_before_shop_loop_item', array( $this, 'hotel_loop_content_wrapper_before' ), 5 );
			add_action( 'woocommerce_after_shop_loop_item', array( $this, 'hotel_loop_content_wrapper_after' ), 15 );

			// Loop items tweaks.
			add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_single_excerpt', 14 );

			/* Homepage Sections Title Wrapper */
			add_action( 'storefront_homepage_before_product_categories', array( $this, 'storefront_homepage_title_wrapper_before' ) );
			add_action( 'storefront_homepage_after_product_categories_title', array( $this, 'storefront_homepage_title_wrapper_after' ), 20 );

			add_action( 'storefront_homepage_before_recent_products', array( $this, 'storefront_homepage_title_wrapper_before' ) );
			add_action( 'storefront_homepage_after_recent_products_title', array( $this, 'storefront_homepage_title_wrapper_after' ), 20 );

			add_action( 'storefront_homepage_before_featured_products', array( $this, 'storefront_homepage_title_wrapper_before' ) );
			add_action( 'storefront_homepage_after_featured_products_title', array( $this, 'storefront_homepage_title_wrapper_after' ), 20 );

			add_action( 'storefront_homepage_before_popular_products', array( $this, 'storefront_homepage_title_wrapper_before' ) );
			add_action( 'storefront_homepage_after_popular_products_title', array( $this, 'storefront_homepage_title_wrapper_after' ), 20 );

			add_action( 'storefront_homepage_before_on_sale_products', array( $this, 'storefront_homepage_title_wrapper_before' ) );
			add_action( 'storefront_homepage_after_on_sale_products_title', array( $this, 'storefront_homepage_title_wrapper_after' ), 20 );

			add_action( 'storefront_homepage_before_best_selling_products', array( $this, 'storefront_homepage_title_wrapper_before' ) );
			add_action( 'storefront_homepage_after_best_selling_products_title', array( $this, 'storefront_homepage_title_wrapper_after' ), 20 );

			/* Move Homepage View More button */
			if ( class_exists( 'SP_Frontend_Homepage' ) ) {
				remove_action( 'storefront_homepage_after_product_categories', 'sp_homepage_product_categories_view_more' );
				remove_action( 'storefront_homepage_after_recent_products', 'sp_homepage_recent_products_view_more' );
				remove_action( 'storefront_homepage_after_featured_products', 'sp_homepage_featured_products_view_more' );
				remove_action( 'storefront_homepage_after_popular_products', 'sp_homepage_top_rated_products_view_more' );
				remove_action( 'storefront_homepage_after_on_sale_products', 'sp_homepage_on_sale_products_view_more' );
				remove_action( 'storefront_homepage_after_best_selling_products', 'sp_homepage_best_selling_products_view_more' );

				add_action( 'storefront_homepage_after_product_categories_title', 'sp_homepage_product_categories_view_more' );
				add_action( 'storefront_homepage_after_recent_products_title', 'sp_homepage_recent_products_view_more' );
				add_action( 'storefront_homepage_after_featured_products_title', 'sp_homepage_featured_products_view_more' );
				add_action( 'storefront_homepage_after_popular_products_title', 'sp_homepage_top_rated_products_view_more' );
				add_action( 'storefront_homepage_after_on_sale_products_title', 'sp_homepage_on_sale_products_view_more' );
				add_action( 'storefront_homepage_after_best_selling_products_title', 'sp_homepage_best_selling_products_view_more' );
			}

			/* Header wrapper */
			add_action( 'storefront_header', array( $this, 'hotel_header_wrapper_open' ), 25 );
			add_action( 'storefront_header', array( $this, 'hotel_header_wrapper_close' ), 99 );

			/* Move booking form */
			if ( storefront_is_woocommerce_activated() && is_product() ) {
				$product = wc_get_product( $post->ID );

				if ( $product && function_exists( 'is_wc_booking_product' ) && is_wc_booking_product( $product ) ) {
					remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
					add_action( 'woocommerce_after_single_product_summary', 'woocommerce_template_single_add_to_cart', 1 );
				}
			}

			if ( version_compare( $storefront_version, '2.3.0', '>=' ) ) {
				remove_action( 'storefront_header', 'storefront_primary_navigation_wrapper', 42 );
				remove_action( 'storefront_header', 'storefront_primary_navigation_wrapper_close', 68 );
				remove_action( 'storefront_header', 'storefront_header_container_close', 41 );
				add_action( 'storefront_header', 'storefront_header_container_close', 100 );
			}
		}

		/**
		 * Primary navigation wrapper
		 *
		 * @return void
		 */
		public function hotel_header_wrapper_open() {
			echo '<div class="hotel-header-wrapper">';
		}

		/**
		 * Primary navigation wrapper
		 *
		 * @return void
		 */
		public function hotel_header_wrapper_close() {
			do_action( 'hotel_header_wrapper_close' );
			echo '</div><!-- .hotel-header-wrapper -->';
		}

		/**
		 * Loop Product Thumbnail Wrapper Before
		 *
		 * @return void
		 */
		public function hotel_loop_thumbnail_wrapper_before() {
			echo '<div class="hotel-thumbnail-content">';
			echo '<a href="' . esc_url( get_permalink( get_the_ID() ) ) . '">';
		}

		/**
		 * Loop Product Thumbnail Wrapper After
		 *
		 * @return void
		 */
		public function hotel_loop_thumbnail_wrapper_after() {
			echo '</a></div><!-- .hotel-thumbnail-content -->';
		}

		/**
		 * Loop Product Content Wrapper Before
		 *
		 * @return void
		 */
		public function hotel_loop_content_wrapper_before() {
			echo '<div class="hotel-product-content">';
		}

		/**
		 * Loop Product Content Wrapper After
		 *
		 * @return void
		 */
		public function hotel_loop_content_wrapper_after() {
			echo '</div><!-- .hotel-product-content -->';
		}

		/**
		 * Homepage Section Title Before
		 *
		 * @return void
		 */
		public function storefront_homepage_title_wrapper_before() {
			echo '<div class="section-title-wrapper">';
		}

		/**
		 * Homepage Section Title After
		 *
		 * @return void
		 */
		public function storefront_homepage_title_wrapper_after() {
			echo '</div><!-- .section-title-wrapper -->';
		}
	}
}

return new Hotel_Template();
